@@ -28,15 +28,27 @@ for(page in 1:2){
      screen(i)
      par(cex=.5)
      par(mai=c(.40,.40,.40,.40)) # margins of plot relative to plotting position
-     plot(discrep[,((page-1)*4+(2*i-1)):((page-1)*4+(2*i))], ylab="Observed", xlab="Simulated", 
+
+     ## Compute plotting limits to generate symmetric plot
+     lims <- range(discrep[,(2*i):(2*i-1)])
+     
+     ## Plot observed vs simulated discrepancies
+     plot(discrep[,((page-1)*4+(2*i)):((page-1)*4+(2*i-1))],
+          xlab="Simulated", ylab="Observed", 
          main=titles[(page-1)*4+i], cex.main=1.5)
      abline(a=0, b=1)
+
+     ## Compute Bayesian p-value
      p.value <- sum(discrep[,(page-1)*4+2*i-1]<discrep[,(page-1)*4+2*i])/nrow(discrep)
-     # locate where to plot
-     x.loc <- min(discrep[,(page-1)*4+2*i-1])+.10*(max(discrep[,(page-1)*4+2*i-1])-min(discrep[,(page-1)*4+2*i-1]))
-     y.loc <- max(discrep[,(page-1)*4+2*i  ])-.10*(max(discrep[,(page-1)*4+2*i  ])-min(discrep[,(page-1)*4+2*i  ]))
-     text(x.loc, y.loc, labels=paste("Bayesian GOF P:",formatC(p.value, digits=2, format="f")), cex=1.5, adj=c(0,0))  
+     
+  ## Add p-value to plot
+  x.loc <- mean(lims)
+  y.loc <- min(lims)
+  
+  text(x.loc, y.loc,
+       labels=paste("Bayesian GOF P:",formatC(p.value, digits=2, format="f")),
+       cex=1.5, adj=c(0,0))  
    }
    close.screen(all=TRUE)     # exit from plots for this page
-   }
+ }
 }
